ForegroundDownloadEvent class

Constructors

ForegroundDownloadEvent({required ForegroundDownloadEventType type, required ForegroundDownloadState state, int? sessionId, String? savePath, int downloadedBytes = 0, int totalBytes = 0, double? progress, String? code, String? message, int networkRetryCount = 0, int validationRetryCount = 0})
const
ForegroundDownloadEvent.fromMap(Map<Object?, Object?> map)
factory

Properties

code String?
final
downloadedBytes int
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
networkRetryCount int
final
progress double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savePath String?
final
sessionId int?
final
state ForegroundDownloadState
final
totalBytes int
final
type ForegroundDownloadEventType
final
validationRetryCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited