OssConfig class

OSS (Alibaba Cloud Object Storage Service) configuration.

Supports two modes:

Constructors

OssConfig({required String accessKeyId, required String accessKeySecret, String? securityToken, required String endpoint, required String bucket})
const

Properties

accessKeyId String
OSS AccessKeyId (from STS response or permanent AK).
final
accessKeySecret String
OSS AccessKeySecret (from STS response or permanent AK).
final
bucket String
OSS bucket name.
final
endpoint String
OSS endpoint, e.g. "oss-cn-hangzhou.aliyuncs.com".
final
hashCode int
The hash code for this object.
no setterinherited
isPublicRead bool
Whether no credentials are provided (public-read bucket).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityToken String?
STS SecurityToken. null or empty for permanent AK or public-read.
final
useStsToken bool
Whether an STS security token is in use.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited