OssSigner class

Generates OSS request signatures for authenticated downloads.

Implements the OSS signature v1 algorithm using HMAC-SHA1.

Constructors

OssSigner()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateHeaders({required OssConfig config, required String downloadUrl, String httpMethod = 'GET', Map<String, String>? additionalHeaders}) Map<String, String>
Build the HTTP headers required to authenticate an OSS GET request.