UpdateInfo class

Constructors

UpdateInfo({required String currentVersion, required String currentBuildNumber, VersionInfo? latestVersion})

Properties

currentBuildNumber String
当前应用构建号
final
currentVersion String
当前应用版本号
final
hashCode int
The hash code for this object.
no setterinherited
latestVersion VersionInfo?
服务端最新版本信息
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited