VersionInfo class

Constructors

VersionInfo({int? id, int? createdAt, int? updatedAt, required UpdateStrategy updateStrategy, required String version, required int buildVersion, required String modifyContent, required String downloadUrl, int apkSize = 0, String apkHashCode = '', String apkPath = ''})
VersionInfo.fromMap(Map<String, dynamic> json)
factory

Properties

apkHashCode String
APK 文件的 MD5 哈希值(可为空字符串,表示跳过校验)
final
apkPath String
服务端 APK 存储路径(一般客户端不使用)
final
apkSize int
APK 文件大小(字节),0 表示未知
final
buildVersion int
构建号,如 46
final
createdAt int?
final
downloadUrl String
APK 下载地址
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
final
modifyContent String
更新说明
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt int?
final
updateStrategy UpdateStrategy
更新策略(0=可选, 1=推荐, 2=强制)
final
version String
语义化版本号,如 "2.2.4"
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited