UpdateStrategy enum

更新策略枚举(与服务端 update_status 字段映射)

Inheritance
Available extensions

Values

optional → const UpdateStrategy

0 - 普通更新,可跳过

const UpdateStrategy(0)

1 - 推荐更新

const UpdateStrategy(1)
forced → const UpdateStrategy

2 - 强制更新,不可跳过

const UpdateStrategy(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromInt(int v) UpdateStrategy

Constants

values → const List<UpdateStrategy>
A constant List of the values in this enum, in order of their declaration.