UpgraderEventType enum
升级流程中的事件类型,覆盖初始化 → 检测 → 下载 → 校验 → 安装全部环节。
Values
- init → const UpgraderEventType
- checkStart → const UpgraderEventType
- checkResponse → const UpgraderEventType
- checkCurrentVersion → const UpgraderEventType
- checkNoUpdate → const UpgraderEventType
- checkNewVersion → const UpgraderEventType
- checkError → const UpgraderEventType
- downloadStart → const UpgraderEventType
- downloadProgress → const UpgraderEventType
- downloadResume → const UpgraderEventType
- downloadConflict → const UpgraderEventType
- downloadPaused → const UpgraderEventType
- downloadComplete → const UpgraderEventType
- downloadError → const UpgraderEventType
- downloadRetry → const UpgraderEventType
- validationStart → const UpgraderEventType
- validationSuccess → const UpgraderEventType
- validationFailed → const UpgraderEventType
- validationSkipped → const UpgraderEventType
- installStart → const UpgraderEventType
- installComplete → const UpgraderEventType
- installError → const UpgraderEventType
- cleanOldFiles → const UpgraderEventType
- log → const UpgraderEventType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UpgraderEventType> - A constant List of the values in this enum, in order of their declaration.