MethodChannelTinyUpgrader class

使用方法通道实现的 TinyUpgraderPlatform

通过MethodChannel与原生Android代码通信

Inheritance

Constructors

MethodChannelTinyUpgrader()

Properties

foregroundDownloadEvents Stream<ForegroundDownloadEvent>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
用于与原生平台交互的方法通道
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelForegroundDownload({bool deleteFile = true}) Future<void>
override
canRequestPackageInstalls() Future<bool>
override
getAvailableStorageBytes(String directoryPath) Future<int>
override
getForegroundDownloadState() Future<ForegroundDownloadEvent>
override
getPlatformVersion() Future<String?>
获得平台版本
override
installApk(String filePath) Future<InstallResult>
直接安装APK文件
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openInstallPermissionSettings() Future<void>
override
pauseForegroundDownload() Future<void>
override
startForegroundDownload(ForegroundDownloadRequest request) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited