TinyUpgraderPlatform class abstract

TinyUpgrader 平台接口

定义了所有平台需要实现的方法

Inheritance
  • Object
  • PlatformInterface
  • TinyUpgraderPlatform
Implementers

Constructors

TinyUpgraderPlatform()
构造函数

Properties

foregroundDownloadEvents Stream<ForegroundDownloadEvent>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelForegroundDownload({bool deleteFile = true}) Future<void>
canRequestPackageInstalls() Future<bool>
getAvailableStorageBytes(String directoryPath) Future<int>
getForegroundDownloadState() Future<ForegroundDownloadEvent>
getPlatformVersion() Future<String?>
获得平台版本
installApk(String filePath) Future<InstallResult>
直接安装APK文件
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openInstallPermissionSettings() Future<void>
pauseForegroundDownload() Future<void>
startForegroundDownload(ForegroundDownloadRequest request) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance TinyUpgraderPlatform
默认的平台实例
getter/setter pair