VersionComparator class

Compares numeric dotted versions such as 1.2, 1.2.0, and v1.2.0.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compare(String left, String right) int
Returns a negative value when left is older, zero when equivalent, and a positive value when left is newer than right.
isUpdateAvailable({required String candidateVersion, required int candidateBuildNumber, required String currentVersion, required String currentBuildNumber}) bool
Returns whether the candidate version/build is strictly newer.