ForegroundDownloadRequest class

Constructors

ForegroundDownloadRequest({required int sessionId, required String url, required String savePath, required Map<String, String> headers, required int expectedSize, required String expectedHash, required String hashAlgorithm, required int maxNetworkRetryCount, required int maxValidationRetryCount, required int minFreeSpaceMarginBytes})
const

Properties

expectedHash String
final
expectedSize int
final
hashAlgorithm String
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
maxNetworkRetryCount int
final
maxValidationRetryCount int
final
minFreeSpaceMarginBytes int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savePath String
final
sessionId int
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited